@@ -1,26 +1,5 @@
-# Copyright (c) 2020 - 2022  Peter Pentchev <roam@ringlet.net>
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
+# SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+# SPDX-License-Identifier: BSD-2-Clause
 """Simple tests for the validation routine."""
 
 from __future__ import annotations
@@ -38,7 +17,7 @@ import trivval
 from . import data as tdata
 
 
-def do_test(value: dict[str, Any], schema: dict[str, Any], backwards: bool = False) -> None:
+def do_test(value: dict[str, Any], schema: dict[str, Any], *, backwards: bool = False) -> None:
     """Run the tests for a specific value against a schema."""
 
     def test_extra_succeed() -> None:
@@ -68,7 +47,7 @@ def do_test(value: dict[str, Any], schema: dict[str, Any], backwards: bool = Fal
     with pytest.raises(trivval.ValidationError) as err:
         trivval.validate_dict(value, schema, 0)
     if not backwards:
-        assert err.value.path == add_path + ["a,more"]
+        assert err.value.path == [*add_path, "a,more"]
         assert err.value.err.startswith("extra")
 
     del add_to["a"]
@@ -80,13 +59,13 @@ def do_test(value: dict[str, Any], schema: dict[str, Any], backwards: bool = Fal
 
     with pytest.raises(trivval.ValidationError) as err:
         trivval.validate_dict(value, schema, trivval.FLAG_ALLOW_EXTRA)
-    assert err.value.path == add_path + ["hostname"]
+    assert err.value.path == [*add_path, "hostname"]
     assert err.value.err.startswith("missing")
 
     with pytest.raises(trivval.ValidationError) as err:
         trivval.validate_dict(value, schema, 0)
     if not backwards:
-        assert err.value.path == add_path + ["hostname"]
+        assert err.value.path == [*add_path, "hostname"]
         assert err.value.err.startswith("missing")
 
     add_to["hostname"] = missing
@@ -157,7 +136,7 @@ def test_schema() -> None:
             assert called == [
                 None,
                 (value, tdata.SCHEMA[version], 0),
-            ]
+            ]  # type: ignore[comparison-overlap]
 
 
 def test_exact_json() -> None:
